@@ -20,6 +20,8 @@ function _aws_cdk_aws_emrserverless_CfnApplication_AutoStartConfigurationPropert
 }
 function _aws_cdk_aws_emrserverless_CfnApplication_AutoStopConfigurationProperty(p) {
 }
+function _aws_cdk_aws_emrserverless_CfnApplication_ImageConfigurationInputProperty(p) {
+}
 function _aws_cdk_aws_emrserverless_CfnApplication_InitialCapacityConfigProperty(p) {
 }
 function _aws_cdk_aws_emrserverless_CfnApplication_InitialCapacityConfigKeyValuePairProperty(p) {
@@ -30,6 +32,8 @@ function _aws_cdk_aws_emrserverless_CfnApplication_NetworkConfigurationProperty(
 }
 function _aws_cdk_aws_emrserverless_CfnApplication_WorkerConfigurationProperty(p) {
 }
+function _aws_cdk_aws_emrserverless_CfnApplication_WorkerTypeSpecificationInputProperty(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -66,4 +70,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_emrserverless_CfnApplicationProps, _aws_cdk_aws_emrserverless_CfnApplication, _aws_cdk_aws_emrserverless_CfnApplication_AutoStartConfigurationProperty, _aws_cdk_aws_emrserverless_CfnApplication_AutoStopConfigurationProperty, _aws_cdk_aws_emrserverless_CfnApplication_InitialCapacityConfigProperty, _aws_cdk_aws_emrserverless_CfnApplication_InitialCapacityConfigKeyValuePairProperty, _aws_cdk_aws_emrserverless_CfnApplication_MaximumAllowedResourcesProperty, _aws_cdk_aws_emrserverless_CfnApplication_NetworkConfigurationProperty, _aws_cdk_aws_emrserverless_CfnApplication_WorkerConfigurationProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_emrserverless_CfnApplicationProps, _aws_cdk_aws_emrserverless_CfnApplication, _aws_cdk_aws_emrserverless_CfnApplication_AutoStartConfigurationProperty, _aws_cdk_aws_emrserverless_CfnApplication_AutoStopConfigurationProperty, _aws_cdk_aws_emrserverless_CfnApplication_ImageConfigurationInputProperty, _aws_cdk_aws_emrserverless_CfnApplication_InitialCapacityConfigProperty, _aws_cdk_aws_emrserverless_CfnApplication_InitialCapacityConfigKeyValuePairProperty, _aws_cdk_aws_emrserverless_CfnApplication_MaximumAllowedResourcesProperty, _aws_cdk_aws_emrserverless_CfnApplication_NetworkConfigurationProperty, _aws_cdk_aws_emrserverless_CfnApplication_WorkerConfigurationProperty, _aws_cdk_aws_emrserverless_CfnApplication_WorkerTypeSpecificationInputProperty };
